# smartytalent-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.1
- Package version: 1.0.0
- Generator version: 7.21.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://help.smartymeet.com](https://help.smartymeet.com)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import smartytalent_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import smartytalent_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import smartytalent_client
from smartytalent_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.dev03-smartymeet.com
# See configuration.py for a list of all supported configuration parameters.
configuration = smartytalent_client.Configuration(
    host = "https://api.dev03-smartymeet.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with smartytalent_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = smartytalent_client.ActionsApi(api_client)

    try:
        # Create Action
        api_instance.create_action()
    except ApiException as e:
        print("Exception when calling ActionsApi->create_action: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.dev03-smartymeet.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActionsApi* | [**create_action**](docs/ActionsApi.md#create_action) | **POST** /v1/actions | Create Action
*ActionsApi* | [**delete_action**](docs/ActionsApi.md#delete_action) | **DELETE** /v1/actions/{actionId} | Delete Action
*ActionsApi* | [**list_actions**](docs/ActionsApi.md#list_actions) | **GET** /v1/actions | List Actions
*ActionsApi* | [**show_action**](docs/ActionsApi.md#show_action) | **GET** /v1/actions/{actionId} | Show Action
*ActionsApi* | [**update_action**](docs/ActionsApi.md#update_action) | **PATCH** /v1/actions/{actionId} | Update Action
*AdsApi* | [**ad_options**](docs/AdsApi.md#ad_options) | **OPTIONS** /v1/ads/{adId} | Ad Options
*AdsApi* | [**ads_options**](docs/AdsApi.md#ads_options) | **OPTIONS** /v1/ads | Ads Options
*AdsApi* | [**create_ad**](docs/AdsApi.md#create_ad) | **POST** /v1/ads | Create Ad
*AdsApi* | [**delete_ad**](docs/AdsApi.md#delete_ad) | **DELETE** /v1/ads/{adId} | Delete Ad
*AdsApi* | [**list_ads**](docs/AdsApi.md#list_ads) | **GET** /v1/ads | List Ads
*AdsApi* | [**show_ad**](docs/AdsApi.md#show_ad) | **GET** /v1/ads/{adId} | Show Ad
*AdsApi* | [**update_ad**](docs/AdsApi.md#update_ad) | **PATCH** /v1/ads/{adId} | Update Ad
*ApikeysApi* | [**apikey_options**](docs/ApikeysApi.md#apikey_options) | **OPTIONS** /v1/apikeys/{apikeyId} | Apikey Options
*ApikeysApi* | [**apikeys_options**](docs/ApikeysApi.md#apikeys_options) | **OPTIONS** /v1/apikeys | Apikeys Options
*ApikeysApi* | [**create_apikey**](docs/ApikeysApi.md#create_apikey) | **POST** /v1/apikeys | Create Apikey
*ApikeysApi* | [**delete_apikey**](docs/ApikeysApi.md#delete_apikey) | **DELETE** /v1/apikeys/{apikeyId} | Delete Apikey
*ApikeysApi* | [**list_apikeys**](docs/ApikeysApi.md#list_apikeys) | **GET** /v1/apikeys | List Apikeys
*ApikeysApi* | [**show_apikey**](docs/ApikeysApi.md#show_apikey) | **GET** /v1/apikeys/{apikeyId} | Show Apikey
*ApikeysApi* | [**update_apikey**](docs/ApikeysApi.md#update_apikey) | **PATCH** /v1/apikeys/{apikeyId} | Update Apikey
*AssessmentsApi* | [**assessment_options**](docs/AssessmentsApi.md#assessment_options) | **OPTIONS** /v1/assessments/{assessmentId} | Assessment Options
*AssessmentsApi* | [**assessments_options**](docs/AssessmentsApi.md#assessments_options) | **OPTIONS** /v1/assessments | Assessments Options
*AssessmentsApi* | [**create_assessment**](docs/AssessmentsApi.md#create_assessment) | **POST** /v1/assessments | Create Assessment
*AssessmentsApi* | [**delete_assessment**](docs/AssessmentsApi.md#delete_assessment) | **DELETE** /v1/assessments/{assessmentId} | Delete Assessment
*AssessmentsApi* | [**list_assessments**](docs/AssessmentsApi.md#list_assessments) | **GET** /v1/assessments | List Assessments
*AssessmentsApi* | [**show_assessment**](docs/AssessmentsApi.md#show_assessment) | **GET** /v1/assessments/{assessmentId} | Show Assessment
*AssessmentsApi* | [**update_assessment**](docs/AssessmentsApi.md#update_assessment) | **PATCH** /v1/assessments/{assessmentId} | Update Assessment
*BrowsersApi* | [**browser_options**](docs/BrowsersApi.md#browser_options) | **OPTIONS** /v1/browsers/{browserId} | Browser Options
*BrowsersApi* | [**browsers_options**](docs/BrowsersApi.md#browsers_options) | **OPTIONS** /v1/browsers | Browsers Options
*BrowsersApi* | [**create_browser**](docs/BrowsersApi.md#create_browser) | **POST** /v1/browsers | Create Browser
*BrowsersApi* | [**delete_browser**](docs/BrowsersApi.md#delete_browser) | **DELETE** /v1/browsers/{browserId} | Delete Browser
*BrowsersApi* | [**list_browsers**](docs/BrowsersApi.md#list_browsers) | **GET** /v1/browsers | List Browsers
*BrowsersApi* | [**show_browser**](docs/BrowsersApi.md#show_browser) | **GET** /v1/browsers/{browserId} | Show Browser
*BrowsersApi* | [**update_browser**](docs/BrowsersApi.md#update_browser) | **PATCH** /v1/browsers/{browserId} | Update Browser
*CallsApi* | [**call_options**](docs/CallsApi.md#call_options) | **OPTIONS** /v1/calls/{callId} | Call Options
*CallsApi* | [**calls_options**](docs/CallsApi.md#calls_options) | **OPTIONS** /v1/calls | Calls Options
*CallsApi* | [**create_call**](docs/CallsApi.md#create_call) | **POST** /v1/calls | Create Call
*CallsApi* | [**delete_call**](docs/CallsApi.md#delete_call) | **DELETE** /v1/calls/{callId} | Delete Call
*CallsApi* | [**list_calls**](docs/CallsApi.md#list_calls) | **GET** /v1/calls | List Calls
*CallsApi* | [**show_call**](docs/CallsApi.md#show_call) | **GET** /v1/calls/{callId} | Show Call
*CallsApi* | [**update_call**](docs/CallsApi.md#update_call) | **PATCH** /v1/calls/{callId} | Update Call
*CandidatesApi* | [**candidate_jobs_options**](docs/CandidatesApi.md#candidate_jobs_options) | **OPTIONS** /v1/candidates/{candidateId}/jobs | Candidate Jobs Options
*CandidatesApi* | [**candidate_jobs_relationships_options**](docs/CandidatesApi.md#candidate_jobs_relationships_options) | **OPTIONS** /v1/candidates/{candidateId}/relationships/jobs | Candidate Jobs Relationships Options
*CandidatesApi* | [**candidate_options**](docs/CandidatesApi.md#candidate_options) | **OPTIONS** /v1/candidates/{candidateId} | Candidate Options
*CandidatesApi* | [**candidate_talents_options**](docs/CandidatesApi.md#candidate_talents_options) | **OPTIONS** /v1/candidates/{candidateId}/talents | Candidate Talents Options
*CandidatesApi* | [**candidate_talents_relationships_options**](docs/CandidatesApi.md#candidate_talents_relationships_options) | **OPTIONS** /v1/candidates/{candidateId}/relationships/talents | Candidate Talents Relationships Options
*CandidatesApi* | [**candidates_options**](docs/CandidatesApi.md#candidates_options) | **OPTIONS** /v1/candidates | Candidates Options
*CandidatesApi* | [**create_candidate**](docs/CandidatesApi.md#create_candidate) | **POST** /v1/candidates | Create Candidate
*CandidatesApi* | [**delete_candidate**](docs/CandidatesApi.md#delete_candidate) | **DELETE** /v1/candidates/{candidateId} | Delete Candidate
*CandidatesApi* | [**list_candidate_jobs**](docs/CandidatesApi.md#list_candidate_jobs) | **GET** /v1/candidates/{candidateId}/jobs | List Candidate Jobs
*CandidatesApi* | [**list_candidate_jobs_relationship**](docs/CandidatesApi.md#list_candidate_jobs_relationship) | **GET** /v1/candidates/{candidateId}/relationships/jobs | List Candidate Jobs Relationship
*CandidatesApi* | [**list_candidate_talents**](docs/CandidatesApi.md#list_candidate_talents) | **GET** /v1/candidates/{candidateId}/talents | List Candidate Talents
*CandidatesApi* | [**list_candidate_talents_relationship**](docs/CandidatesApi.md#list_candidate_talents_relationship) | **GET** /v1/candidates/{candidateId}/relationships/talents | List Candidate Talents Relationship
*CandidatesApi* | [**list_candidates**](docs/CandidatesApi.md#list_candidates) | **GET** /v1/candidates | List Candidates
*CandidatesApi* | [**show_candidate**](docs/CandidatesApi.md#show_candidate) | **GET** /v1/candidates/{candidateId} | Show Candidate
*CandidatesApi* | [**update_candidate**](docs/CandidatesApi.md#update_candidate) | **PATCH** /v1/candidates/{candidateId} | Update Candidate
*ChatsApi* | [**chat_options**](docs/ChatsApi.md#chat_options) | **OPTIONS** /v1/chats/{chatId} | Chat Options
*ChatsApi* | [**chats_options**](docs/ChatsApi.md#chats_options) | **OPTIONS** /v1/chats | Chats Options
*ChatsApi* | [**create_chat**](docs/ChatsApi.md#create_chat) | **POST** /v1/chats | Create Chat
*ChatsApi* | [**delete_chat**](docs/ChatsApi.md#delete_chat) | **DELETE** /v1/chats/{chatId} | Delete Chat
*ChatsApi* | [**list_chats**](docs/ChatsApi.md#list_chats) | **GET** /v1/chats | List Chats
*ChatsApi* | [**show_chat**](docs/ChatsApi.md#show_chat) | **GET** /v1/chats/{chatId} | Show Chat
*ChatsApi* | [**update_chat**](docs/ChatsApi.md#update_chat) | **PATCH** /v1/chats/{chatId} | Update Chat
*ConversationsApi* | [**conversation_options**](docs/ConversationsApi.md#conversation_options) | **OPTIONS** /v1/conversations/{conversationId} | Conversation Options
*ConversationsApi* | [**conversations_options**](docs/ConversationsApi.md#conversations_options) | **OPTIONS** /v1/conversations | Conversations Options
*ConversationsApi* | [**create_conversation**](docs/ConversationsApi.md#create_conversation) | **POST** /v1/conversations | Create Conversation
*ConversationsApi* | [**delete_conversation**](docs/ConversationsApi.md#delete_conversation) | **DELETE** /v1/conversations/{conversationId} | Delete Conversation
*ConversationsApi* | [**list_conversations**](docs/ConversationsApi.md#list_conversations) | **GET** /v1/conversations | List Conversations
*ConversationsApi* | [**show_conversation**](docs/ConversationsApi.md#show_conversation) | **GET** /v1/conversations/{conversationId} | Show Conversation
*ConversationsApi* | [**update_conversation**](docs/ConversationsApi.md#update_conversation) | **PATCH** /v1/conversations/{conversationId} | Update Conversation
*EmailsApi* | [**create_email**](docs/EmailsApi.md#create_email) | **POST** /v1/emails | Create Email
*EmailsApi* | [**delete_email**](docs/EmailsApi.md#delete_email) | **DELETE** /v1/emails/{emailId} | Delete Email
*EmailsApi* | [**email_options**](docs/EmailsApi.md#email_options) | **OPTIONS** /v1/emails/{emailId} | Email Options
*EmailsApi* | [**emails_options**](docs/EmailsApi.md#emails_options) | **OPTIONS** /v1/emails | Emails Options
*EmailsApi* | [**list_emails**](docs/EmailsApi.md#list_emails) | **GET** /v1/emails | List Emails
*EmailsApi* | [**show_email**](docs/EmailsApi.md#show_email) | **GET** /v1/emails/{emailId} | Show Email
*EmailsApi* | [**update_email**](docs/EmailsApi.md#update_email) | **PATCH** /v1/emails/{emailId} | Update Email
*FilesApi* | [**create_file**](docs/FilesApi.md#create_file) | **POST** /v1/files | Create File
*FilesApi* | [**delete_file**](docs/FilesApi.md#delete_file) | **DELETE** /v1/files/{fileId} | Delete File
*FilesApi* | [**file_options**](docs/FilesApi.md#file_options) | **OPTIONS** /v1/files/{fileId} | File Options
*FilesApi* | [**files_options**](docs/FilesApi.md#files_options) | **OPTIONS** /v1/files | Files Options
*FilesApi* | [**list_files**](docs/FilesApi.md#list_files) | **GET** /v1/files | List Files
*FilesApi* | [**show_file**](docs/FilesApi.md#show_file) | **GET** /v1/files/{fileId} | Show File
*FilesApi* | [**update_file**](docs/FilesApi.md#update_file) | **PATCH** /v1/files/{fileId} | Update File
*FindersApi* | [**create_finder**](docs/FindersApi.md#create_finder) | **POST** /v1/finders | Create Finder
*FindersApi* | [**delete_finder**](docs/FindersApi.md#delete_finder) | **DELETE** /v1/finders/{finderId} | Delete Finder
*FindersApi* | [**finder_options**](docs/FindersApi.md#finder_options) | **OPTIONS** /v1/finders/{finderId} | Finder Options
*FindersApi* | [**finders_options**](docs/FindersApi.md#finders_options) | **OPTIONS** /v1/finders | Finders Options
*FindersApi* | [**list_finders**](docs/FindersApi.md#list_finders) | **GET** /v1/finders | List Finders
*FindersApi* | [**show_finder**](docs/FindersApi.md#show_finder) | **GET** /v1/finders/{finderId} | Show Finder
*FindersApi* | [**update_finder**](docs/FindersApi.md#update_finder) | **PATCH** /v1/finders/{finderId} | Update Finder
*FormsApi* | [**create_form**](docs/FormsApi.md#create_form) | **POST** /v1/forms | Create Form
*FormsApi* | [**delete_form**](docs/FormsApi.md#delete_form) | **DELETE** /v1/forms/{formId} | Delete Form
*FormsApi* | [**form_options**](docs/FormsApi.md#form_options) | **OPTIONS** /v1/forms/{formId} | Form Options
*FormsApi* | [**forms_options**](docs/FormsApi.md#forms_options) | **OPTIONS** /v1/forms | Forms Options
*FormsApi* | [**list_forms**](docs/FormsApi.md#list_forms) | **GET** /v1/forms | List Forms
*FormsApi* | [**show_form**](docs/FormsApi.md#show_form) | **GET** /v1/forms/{formId} | Show Form
*FormsApi* | [**update_form**](docs/FormsApi.md#update_form) | **PATCH** /v1/forms/{formId} | Update Form
*JobsApi* | [**create_job**](docs/JobsApi.md#create_job) | **POST** /v1/jobs | Create Job
*JobsApi* | [**delete_job**](docs/JobsApi.md#delete_job) | **DELETE** /v1/jobs/{jobId} | Delete Job
*JobsApi* | [**job_candidates_options**](docs/JobsApi.md#job_candidates_options) | **OPTIONS** /v1/jobs/{jobId}/candidates | Job Candidates Options
*JobsApi* | [**job_candidates_relationships_options**](docs/JobsApi.md#job_candidates_relationships_options) | **OPTIONS** /v1/jobs/{jobId}/relationships/candidates | Job Candidates Relationships Options
*JobsApi* | [**job_options**](docs/JobsApi.md#job_options) | **OPTIONS** /v1/jobs/{jobId} | Job Options
*JobsApi* | [**jobs_options**](docs/JobsApi.md#jobs_options) | **OPTIONS** /v1/jobs | Jobs Options
*JobsApi* | [**list_job_candidates**](docs/JobsApi.md#list_job_candidates) | **GET** /v1/jobs/{jobId}/candidates | List Job Candidates
*JobsApi* | [**list_job_candidates_relationship**](docs/JobsApi.md#list_job_candidates_relationship) | **GET** /v1/jobs/{jobId}/relationships/candidates | List Job Candidates Relationship
*JobsApi* | [**list_jobs**](docs/JobsApi.md#list_jobs) | **GET** /v1/jobs | List Jobs
*JobsApi* | [**show_job**](docs/JobsApi.md#show_job) | **GET** /v1/jobs/{jobId} | Show Job
*JobsApi* | [**update_job**](docs/JobsApi.md#update_job) | **PATCH** /v1/jobs/{jobId} | Update Job
*LinksApi* | [**create_link**](docs/LinksApi.md#create_link) | **POST** /v1/links | Create Link
*LinksApi* | [**delete_link**](docs/LinksApi.md#delete_link) | **DELETE** /v1/links/{linkId} | Delete Link
*LinksApi* | [**link_options**](docs/LinksApi.md#link_options) | **OPTIONS** /v1/links/{linkId} | Link Options
*LinksApi* | [**links_options**](docs/LinksApi.md#links_options) | **OPTIONS** /v1/links | Links Options
*LinksApi* | [**list_links**](docs/LinksApi.md#list_links) | **GET** /v1/links | List Links
*LinksApi* | [**show_link**](docs/LinksApi.md#show_link) | **GET** /v1/links/{linkId} | Show Link
*LinksApi* | [**update_link**](docs/LinksApi.md#update_link) | **PATCH** /v1/links/{linkId} | Update Link
*MeetingsApi* | [**create_meeting**](docs/MeetingsApi.md#create_meeting) | **POST** /v1/meetings | Create Meeting
*MeetingsApi* | [**create_meeting_ai_session**](docs/MeetingsApi.md#create_meeting_ai_session) | **POST** /v1/meetings/{meetingId}/ai-session | Create Meeting AI Session
*MeetingsApi* | [**create_meeting_attendee**](docs/MeetingsApi.md#create_meeting_attendee) | **POST** /v1/meetings/{meetingId}/attendees | Create Meeting Attendee
*MeetingsApi* | [**delete_meeting**](docs/MeetingsApi.md#delete_meeting) | **DELETE** /v1/meetings/{meetingId} | Delete Meeting
*MeetingsApi* | [**list_meetings**](docs/MeetingsApi.md#list_meetings) | **GET** /v1/meetings | List Meetings
*MeetingsApi* | [**meeting_ai_session_options**](docs/MeetingsApi.md#meeting_ai_session_options) | **OPTIONS** /v1/meetings/{meetingId}/ai-session | Meeting AI Session Options
*MeetingsApi* | [**meeting_attendees_options**](docs/MeetingsApi.md#meeting_attendees_options) | **OPTIONS** /v1/meetings/{meetingId}/attendees | Meeting Attendees Options
*MeetingsApi* | [**meeting_lobby_options**](docs/MeetingsApi.md#meeting_lobby_options) | **OPTIONS** /v1/meetings/{meetingId}/lobby | Meeting Lobby Options
*MeetingsApi* | [**meeting_options**](docs/MeetingsApi.md#meeting_options) | **OPTIONS** /v1/meetings/{meetingId} | Meeting Options
*MeetingsApi* | [**meeting_transcription**](docs/MeetingsApi.md#meeting_transcription) | **POST** /v1/meetings/{meetingId}/transcription | Manage Meeting Transcription
*MeetingsApi* | [**meeting_transcription_options**](docs/MeetingsApi.md#meeting_transcription_options) | **OPTIONS** /v1/meetings/{meetingId}/transcription | Meeting Transcription Options
*MeetingsApi* | [**meetings_options**](docs/MeetingsApi.md#meetings_options) | **OPTIONS** /v1/meetings | Meetings Options
*MeetingsApi* | [**show_meeting**](docs/MeetingsApi.md#show_meeting) | **GET** /v1/meetings/{meetingId} | Show Meeting
*MeetingsApi* | [**show_meeting_lobby**](docs/MeetingsApi.md#show_meeting_lobby) | **GET** /v1/meetings/{meetingId}/lobby | Show Meeting Lobby
*MeetingsApi* | [**update_meeting**](docs/MeetingsApi.md#update_meeting) | **PATCH** /v1/meetings/{meetingId} | Update Meeting
*NotesApi* | [**create_note**](docs/NotesApi.md#create_note) | **POST** /v1/notes | Create Note
*NotesApi* | [**delete_note**](docs/NotesApi.md#delete_note) | **DELETE** /v1/notes/{noteId} | Delete Note
*NotesApi* | [**list_notes**](docs/NotesApi.md#list_notes) | **GET** /v1/notes | List Notes
*NotesApi* | [**note_options**](docs/NotesApi.md#note_options) | **OPTIONS** /v1/notes/{noteId} | Note Options
*NotesApi* | [**notes_options**](docs/NotesApi.md#notes_options) | **OPTIONS** /v1/notes | Notes Options
*NotesApi* | [**show_note**](docs/NotesApi.md#show_note) | **GET** /v1/notes/{noteId} | Show Note
*NotesApi* | [**update_note**](docs/NotesApi.md#update_note) | **PATCH** /v1/notes/{noteId} | Update Note
*NotificationsApi* | [**create_notification**](docs/NotificationsApi.md#create_notification) | **POST** /v1/notifications | Create Notification
*NotificationsApi* | [**delete_notification**](docs/NotificationsApi.md#delete_notification) | **DELETE** /v1/notifications/{notificationId} | Delete Notification
*NotificationsApi* | [**get_notification**](docs/NotificationsApi.md#get_notification) | **GET** /v1/notifications/{notificationId} | Get Notification
*NotificationsApi* | [**list_notifications**](docs/NotificationsApi.md#list_notifications) | **GET** /v1/notifications | List Notifications
*NotificationsApi* | [**notification_options**](docs/NotificationsApi.md#notification_options) | **OPTIONS** /v1/notifications/{notificationId} | Notification Options
*NotificationsApi* | [**notifications_options**](docs/NotificationsApi.md#notifications_options) | **OPTIONS** /v1/notifications | Notifications Options
*NotificationsApi* | [**update_notification**](docs/NotificationsApi.md#update_notification) | **PATCH** /v1/notifications/{notificationId} | Update Notification
*OperationsApi* | [**create_operation**](docs/OperationsApi.md#create_operation) | **POST** /v1/operations | Create Operation
*OperationsApi* | [**delete_operation**](docs/OperationsApi.md#delete_operation) | **DELETE** /v1/operations/{operationId} | Delete Operation
*OperationsApi* | [**list_operations**](docs/OperationsApi.md#list_operations) | **GET** /v1/operations | List Operations
*OperationsApi* | [**operation_options**](docs/OperationsApi.md#operation_options) | **OPTIONS** /v1/operations/{operationId} | Operation Options
*OperationsApi* | [**operations_options**](docs/OperationsApi.md#operations_options) | **OPTIONS** /v1/operations | Operations Options
*OperationsApi* | [**show_operation**](docs/OperationsApi.md#show_operation) | **GET** /v1/operations/{operationId} | Show Operation
*OperationsApi* | [**update_operation**](docs/OperationsApi.md#update_operation) | **PATCH** /v1/operations/{operationId} | Update Operation
*PersonasApi* | [**create_persona**](docs/PersonasApi.md#create_persona) | **POST** /v1/personas | Create Persona
*PersonasApi* | [**delete_persona**](docs/PersonasApi.md#delete_persona) | **DELETE** /v1/personas/{personaId} | Delete Persona
*PersonasApi* | [**list_personas**](docs/PersonasApi.md#list_personas) | **GET** /v1/personas | List Personas
*PersonasApi* | [**persona_options**](docs/PersonasApi.md#persona_options) | **OPTIONS** /v1/personas/{personaId} | Persona Options
*PersonasApi* | [**personas_options**](docs/PersonasApi.md#personas_options) | **OPTIONS** /v1/personas | Personas Options
*PersonasApi* | [**show_persona**](docs/PersonasApi.md#show_persona) | **GET** /v1/personas/{personaId} | Show Persona
*PersonasApi* | [**update_persona**](docs/PersonasApi.md#update_persona) | **PATCH** /v1/personas/{personaId} | Update Persona
*ReportsApi* | [**create_report**](docs/ReportsApi.md#create_report) | **POST** /v1/reports | Create Report
*ReportsApi* | [**delete_report**](docs/ReportsApi.md#delete_report) | **DELETE** /v1/reports/{reportId} | Delete Report
*ReportsApi* | [**list_reports**](docs/ReportsApi.md#list_reports) | **GET** /v1/reports | List Reports
*ReportsApi* | [**report_options**](docs/ReportsApi.md#report_options) | **OPTIONS** /v1/reports/{reportId} | Report Options
*ReportsApi* | [**reports_options**](docs/ReportsApi.md#reports_options) | **OPTIONS** /v1/reports | Reports Options
*ReportsApi* | [**show_report**](docs/ReportsApi.md#show_report) | **GET** /v1/reports/{reportId} | Show Report
*ReportsApi* | [**update_report**](docs/ReportsApi.md#update_report) | **PATCH** /v1/reports/{reportId} | Update Report
*RolesApi* | [**create_role**](docs/RolesApi.md#create_role) | **POST** /v1/roles | Create Role
*RolesApi* | [**delete_role**](docs/RolesApi.md#delete_role) | **DELETE** /v1/roles/{roleId} | Delete Role
*RolesApi* | [**list_role_users**](docs/RolesApi.md#list_role_users) | **GET** /v1/roles/{roleId}/users | List Role Users
*RolesApi* | [**list_role_users_relationship**](docs/RolesApi.md#list_role_users_relationship) | **GET** /v1/roles/{roleId}/relationships/users | List Role Users Relationship
*RolesApi* | [**list_roles**](docs/RolesApi.md#list_roles) | **GET** /v1/roles | List Roles
*RolesApi* | [**role_options**](docs/RolesApi.md#role_options) | **OPTIONS** /v1/roles/{roleId} | Role Options
*RolesApi* | [**role_users_options**](docs/RolesApi.md#role_users_options) | **OPTIONS** /v1/roles/{roleId}/users | Role Users Options
*RolesApi* | [**role_users_relationships_options**](docs/RolesApi.md#role_users_relationships_options) | **OPTIONS** /v1/roles/{roleId}/relationships/users | Role Users Relationships Options
*RolesApi* | [**roles_options**](docs/RolesApi.md#roles_options) | **OPTIONS** /v1/roles | Roles Options
*RolesApi* | [**show_role**](docs/RolesApi.md#show_role) | **GET** /v1/roles/{roleId} | Show Role
*RolesApi* | [**update_role**](docs/RolesApi.md#update_role) | **PATCH** /v1/roles/{roleId} | Update Role
*RunsApi* | [**cancel_run**](docs/RunsApi.md#cancel_run) | **POST** /v1/runs/{runId}/cancel | Cancel Run
*RunsApi* | [**create_run**](docs/RunsApi.md#create_run) | **POST** /v1/runs | Create Run
*RunsApi* | [**list_runs**](docs/RunsApi.md#list_runs) | **GET** /v1/runs | List Runs
*RunsApi* | [**retry_run**](docs/RunsApi.md#retry_run) | **POST** /v1/runs/{runId}/retry | Retry Run
*RunsApi* | [**show_run**](docs/RunsApi.md#show_run) | **GET** /v1/runs/{runId} | Show Run
*TalentsApi* | [**create_talent**](docs/TalentsApi.md#create_talent) | **POST** /v1/talents | Create Talent
*TalentsApi* | [**delete_talent**](docs/TalentsApi.md#delete_talent) | **DELETE** /v1/talents/{talentId} | Delete Talent
*TalentsApi* | [**list_talent_candidates**](docs/TalentsApi.md#list_talent_candidates) | **GET** /v1/talents/{talentId}/candidates | List Talent Candidates
*TalentsApi* | [**list_talent_candidates_relationship**](docs/TalentsApi.md#list_talent_candidates_relationship) | **GET** /v1/talents/{talentId}/relationships/candidates | List Talent Candidates Relationship
*TalentsApi* | [**list_talents**](docs/TalentsApi.md#list_talents) | **GET** /v1/talents | List Talents
*TalentsApi* | [**show_talent**](docs/TalentsApi.md#show_talent) | **GET** /v1/talents/{talentId} | Show Talent
*TalentsApi* | [**talent_candidates_options**](docs/TalentsApi.md#talent_candidates_options) | **OPTIONS** /v1/talents/{talentId}/candidates | Talent Candidates Options
*TalentsApi* | [**talent_candidates_relationships_options**](docs/TalentsApi.md#talent_candidates_relationships_options) | **OPTIONS** /v1/talents/{talentId}/relationships/candidates | Talent Candidates Relationships Options
*TalentsApi* | [**talent_options**](docs/TalentsApi.md#talent_options) | **OPTIONS** /v1/talents/{talentId} | Talent Options
*TalentsApi* | [**talents_options**](docs/TalentsApi.md#talents_options) | **OPTIONS** /v1/talents | Talents Options
*TalentsApi* | [**update_talent**](docs/TalentsApi.md#update_talent) | **PATCH** /v1/talents/{talentId} | Update Talent
*TenantsApi* | [**create_tenant**](docs/TenantsApi.md#create_tenant) | **POST** /v1/tenants | Create Tenant
*TenantsApi* | [**create_tenant_upload**](docs/TenantsApi.md#create_tenant_upload) | **POST** /v1/tenants/{tenantId}/uploads | Create Tenant Upload
*TenantsApi* | [**delete_tenant**](docs/TenantsApi.md#delete_tenant) | **DELETE** /v1/tenants/{tenantId} | Delete Tenant
*TenantsApi* | [**list_tenants**](docs/TenantsApi.md#list_tenants) | **GET** /v1/tenants | List Tenants
*TenantsApi* | [**purchase_tenant_phone_number**](docs/TenantsApi.md#purchase_tenant_phone_number) | **POST** /v1/tenants/{tenantId}/phone-numbers | Purchase Phone Number
*TenantsApi* | [**release_tenant_phone_number**](docs/TenantsApi.md#release_tenant_phone_number) | **DELETE** /v1/tenants/{tenantId}/phone-numbers | Release Phone Number
*TenantsApi* | [**search_tenant_phone_numbers**](docs/TenantsApi.md#search_tenant_phone_numbers) | **GET** /v1/tenants/{tenantId}/phone-numbers/search | Search Available Phone Numbers
*TenantsApi* | [**show_tenant**](docs/TenantsApi.md#show_tenant) | **GET** /v1/tenants/{tenantId} | Show Tenant
*TenantsApi* | [**tenant_options**](docs/TenantsApi.md#tenant_options) | **OPTIONS** /v1/tenants/{tenantId} | Tenant Options
*TenantsApi* | [**tenant_phone_numbers_options**](docs/TenantsApi.md#tenant_phone_numbers_options) | **OPTIONS** /v1/tenants/{tenantId}/phone-numbers | Phone Numbers Options
*TenantsApi* | [**tenant_phone_numbers_search_options**](docs/TenantsApi.md#tenant_phone_numbers_search_options) | **OPTIONS** /v1/tenants/{tenantId}/phone-numbers/search | Phone Numbers Search Options
*TenantsApi* | [**tenant_uploads_options**](docs/TenantsApi.md#tenant_uploads_options) | **OPTIONS** /v1/tenants/{tenantId}/uploads | Tenant Uploads Options
*TenantsApi* | [**tenants_options**](docs/TenantsApi.md#tenants_options) | **OPTIONS** /v1/tenants | Tenants Options
*TenantsApi* | [**update_tenant**](docs/TenantsApi.md#update_tenant) | **PATCH** /v1/tenants/{tenantId} | Update Tenant
*TimelinesApi* | [**list_timelines**](docs/TimelinesApi.md#list_timelines) | **GET** /v1/timelines | List Timelines
*TimelinesApi* | [**rollback_timeline**](docs/TimelinesApi.md#rollback_timeline) | **POST** /v1/timelines/{timelineId}/rollback | Rollback Timeline Entry
*TimelinesApi* | [**show_timeline**](docs/TimelinesApi.md#show_timeline) | **GET** /v1/timelines/{timelineId} | Show Timeline Entry
*TranslationsApi* | [**create_translation**](docs/TranslationsApi.md#create_translation) | **POST** /v1/translations | Create Translation
*TranslationsApi* | [**delete_translation**](docs/TranslationsApi.md#delete_translation) | **DELETE** /v1/translations/{translationId} | Delete Translation
*TranslationsApi* | [**list_translations**](docs/TranslationsApi.md#list_translations) | **GET** /v1/translations | List Translations
*TranslationsApi* | [**show_translation**](docs/TranslationsApi.md#show_translation) | **GET** /v1/translations/{translationId} | Show Translation
*TranslationsApi* | [**translation_options**](docs/TranslationsApi.md#translation_options) | **OPTIONS** /v1/translations/{translationId} | Translation Options
*TranslationsApi* | [**translations_options**](docs/TranslationsApi.md#translations_options) | **OPTIONS** /v1/translations | Translations Options
*TranslationsApi* | [**update_translation**](docs/TranslationsApi.md#update_translation) | **PATCH** /v1/translations/{translationId} | Update Translation
*TriggersApi* | [**create_trigger**](docs/TriggersApi.md#create_trigger) | **POST** /v1/triggers | Create Trigger
*TriggersApi* | [**delete_trigger**](docs/TriggersApi.md#delete_trigger) | **DELETE** /v1/triggers/{triggerId} | Delete Trigger
*TriggersApi* | [**list_triggers**](docs/TriggersApi.md#list_triggers) | **GET** /v1/triggers | List Triggers
*TriggersApi* | [**show_trigger**](docs/TriggersApi.md#show_trigger) | **GET** /v1/triggers/{triggerId} | Show Trigger
*TriggersApi* | [**update_trigger**](docs/TriggersApi.md#update_trigger) | **PATCH** /v1/triggers/{triggerId} | Update Trigger
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /v1/users | Create User
*UsersApi* | [**create_user_upload**](docs/UsersApi.md#create_user_upload) | **POST** /v1/users/{userId}/uploads | Create User Upload
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /v1/users/{userId} | Delete User
*UsersApi* | [**list_user_apikeys**](docs/UsersApi.md#list_user_apikeys) | **GET** /v1/users/{userId}/apikeys | List User Apikeys
*UsersApi* | [**list_user_apikeys_relationship**](docs/UsersApi.md#list_user_apikeys_relationship) | **GET** /v1/users/{userId}/relationships/apikeys | List User Apikeys Relationship
*UsersApi* | [**list_user_jobs**](docs/UsersApi.md#list_user_jobs) | **GET** /v1/users/{userId}/jobs | List User Jobs
*UsersApi* | [**list_user_jobs_relationship**](docs/UsersApi.md#list_user_jobs_relationship) | **GET** /v1/users/{userId}/relationships/jobs | List User Jobs Relationship
*UsersApi* | [**list_user_roles**](docs/UsersApi.md#list_user_roles) | **GET** /v1/users/{userId}/roles | List User Roles
*UsersApi* | [**list_user_roles_relationship**](docs/UsersApi.md#list_user_roles_relationship) | **GET** /v1/users/{userId}/relationships/roles | List User Roles Relationship
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /v1/users | List Users
*UsersApi* | [**show_user**](docs/UsersApi.md#show_user) | **GET** /v1/users/{userId} | Show User
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PATCH** /v1/users/{userId} | Update User
*UsersApi* | [**user_apikeys_options**](docs/UsersApi.md#user_apikeys_options) | **OPTIONS** /v1/users/{userId}/apikeys | User Apikeys Options
*UsersApi* | [**user_apikeys_relationships_options**](docs/UsersApi.md#user_apikeys_relationships_options) | **OPTIONS** /v1/users/{userId}/relationships/apikeys | User Apikeys Relationships Options
*UsersApi* | [**user_jobs_options**](docs/UsersApi.md#user_jobs_options) | **OPTIONS** /v1/users/{userId}/jobs | User Jobs Options
*UsersApi* | [**user_jobs_relationships_options**](docs/UsersApi.md#user_jobs_relationships_options) | **OPTIONS** /v1/users/{userId}/relationships/jobs | User Jobs Relationships Options
*UsersApi* | [**user_options**](docs/UsersApi.md#user_options) | **OPTIONS** /v1/users/{userId} | User Options
*UsersApi* | [**user_roles_options**](docs/UsersApi.md#user_roles_options) | **OPTIONS** /v1/users/{userId}/roles | User Roles Options
*UsersApi* | [**user_roles_relationships_options**](docs/UsersApi.md#user_roles_relationships_options) | **OPTIONS** /v1/users/{userId}/relationships/roles | User Roles Relationships Options
*UsersApi* | [**user_uploads_options**](docs/UsersApi.md#user_uploads_options) | **OPTIONS** /v1/users/{userId}/uploads | User Uploads Options
*UsersApi* | [**users_options**](docs/UsersApi.md#users_options) | **OPTIONS** /v1/users | Users Options
*WebhooksApi* | [**create_webhook**](docs/WebhooksApi.md#create_webhook) | **POST** /v1/webhooks | Create Webhook
*WebhooksApi* | [**delete_webhook**](docs/WebhooksApi.md#delete_webhook) | **DELETE** /v1/webhooks/{webhookId} | Delete Webhook
*WebhooksApi* | [**list_webhooks**](docs/WebhooksApi.md#list_webhooks) | **GET** /v1/webhooks | List Webhooks
*WebhooksApi* | [**show_webhook**](docs/WebhooksApi.md#show_webhook) | **GET** /v1/webhooks/{webhookId} | Show Webhook
*WebhooksApi* | [**update_webhook**](docs/WebhooksApi.md#update_webhook) | **PATCH** /v1/webhooks/{webhookId} | Update Webhook
*WebhooksApi* | [**webhook_options**](docs/WebhooksApi.md#webhook_options) | **OPTIONS** /v1/webhooks/{webhookId} | Webhook Options
*WebhooksApi* | [**webhooks_options**](docs/WebhooksApi.md#webhooks_options) | **OPTIONS** /v1/webhooks | Webhooks Options
*WorkflowsApi* | [**create_workflow**](docs/WorkflowsApi.md#create_workflow) | **POST** /v1/workflows | Create Workflow
*WorkflowsApi* | [**delete_workflow**](docs/WorkflowsApi.md#delete_workflow) | **DELETE** /v1/workflows/{workflowId} | Delete Workflow
*WorkflowsApi* | [**list_workflows**](docs/WorkflowsApi.md#list_workflows) | **GET** /v1/workflows | List Workflows
*WorkflowsApi* | [**show_workflow**](docs/WorkflowsApi.md#show_workflow) | **GET** /v1/workflows/{workflowId} | Show Workflow
*WorkflowsApi* | [**update_workflow**](docs/WorkflowsApi.md#update_workflow) | **PATCH** /v1/workflows/{workflowId} | Update Workflow
*DefaultApi* | [**cors_timeline_entry**](docs/DefaultApi.md#cors_timeline_entry) | **OPTIONS** /v1/timelines/{timelineId} | CORS support for Timeline Entry
*DefaultApi* | [**cors_timeline_rollback**](docs/DefaultApi.md#cors_timeline_rollback) | **OPTIONS** /v1/timelines/{timelineId}/rollback | CORS support for Timeline Rollback
*DefaultApi* | [**cors_timelines**](docs/DefaultApi.md#cors_timelines) | **OPTIONS** /v1/timelines | CORS support for Timelines


## Documentation For Models

 - [AdAttributesSchema](docs/AdAttributesSchema.md)
 - [AdAttributesSchemaImagesInner](docs/AdAttributesSchemaImagesInner.md)
 - [AdRelationshipsJobDataSchema](docs/AdRelationshipsJobDataSchema.md)
 - [AdRelationshipsJobSchema](docs/AdRelationshipsJobSchema.md)
 - [AdRelationshipsSchema](docs/AdRelationshipsSchema.md)
 - [AdResourceSchema](docs/AdResourceSchema.md)
 - [AdSchema](docs/AdSchema.md)
 - [AdsSchema](docs/AdsSchema.md)
 - [ApikeyAttributesSchema](docs/ApikeyAttributesSchema.md)
 - [ApikeyRelationshipsSchema](docs/ApikeyRelationshipsSchema.md)
 - [ApikeyRelationshipsUserDataSchema](docs/ApikeyRelationshipsUserDataSchema.md)
 - [ApikeyRelationshipsUserSchema](docs/ApikeyRelationshipsUserSchema.md)
 - [ApikeyResourceSchema](docs/ApikeyResourceSchema.md)
 - [ApikeySchema](docs/ApikeySchema.md)
 - [ApikeysSchema](docs/ApikeysSchema.md)
 - [AssessmentAttributesSchema](docs/AssessmentAttributesSchema.md)
 - [AssessmentRelationshipsCandidateDataSchema](docs/AssessmentRelationshipsCandidateDataSchema.md)
 - [AssessmentRelationshipsCandidateSchema](docs/AssessmentRelationshipsCandidateSchema.md)
 - [AssessmentRelationshipsJobDataSchema](docs/AssessmentRelationshipsJobDataSchema.md)
 - [AssessmentRelationshipsJobSchema](docs/AssessmentRelationshipsJobSchema.md)
 - [AssessmentRelationshipsSchema](docs/AssessmentRelationshipsSchema.md)
 - [AssessmentResourceSchema](docs/AssessmentResourceSchema.md)
 - [AssessmentSchema](docs/AssessmentSchema.md)
 - [AssessmentsSchema](docs/AssessmentsSchema.md)
 - [BrowserAttributesSchema](docs/BrowserAttributesSchema.md)
 - [BrowserRelationshipsSchema](docs/BrowserRelationshipsSchema.md)
 - [BrowserRelationshipsTranslationsDataSchema](docs/BrowserRelationshipsTranslationsDataSchema.md)
 - [BrowserRelationshipsTranslationsSchema](docs/BrowserRelationshipsTranslationsSchema.md)
 - [BrowserResourceSchema](docs/BrowserResourceSchema.md)
 - [BrowserSchema](docs/BrowserSchema.md)
 - [BrowsersSchema](docs/BrowsersSchema.md)
 - [CallAttributesSchema](docs/CallAttributesSchema.md)
 - [CallRelationshipsSchema](docs/CallRelationshipsSchema.md)
 - [CallRelationshipsTranslationsDataSchema](docs/CallRelationshipsTranslationsDataSchema.md)
 - [CallRelationshipsTranslationsSchema](docs/CallRelationshipsTranslationsSchema.md)
 - [CallResourceSchema](docs/CallResourceSchema.md)
 - [CallSchema](docs/CallSchema.md)
 - [CallsSchema](docs/CallsSchema.md)
 - [CandidateAttributesSchema](docs/CandidateAttributesSchema.md)
 - [CandidateCriteriaSchema](docs/CandidateCriteriaSchema.md)
 - [CandidateRelationshipsJobDataSchema](docs/CandidateRelationshipsJobDataSchema.md)
 - [CandidateRelationshipsJobSchema](docs/CandidateRelationshipsJobSchema.md)
 - [CandidateRelationshipsOperationsDataSchema](docs/CandidateRelationshipsOperationsDataSchema.md)
 - [CandidateRelationshipsOperationsSchema](docs/CandidateRelationshipsOperationsSchema.md)
 - [CandidateRelationshipsSchema](docs/CandidateRelationshipsSchema.md)
 - [CandidateRelationshipsTalentDataSchema](docs/CandidateRelationshipsTalentDataSchema.md)
 - [CandidateRelationshipsTalentSchema](docs/CandidateRelationshipsTalentSchema.md)
 - [CandidateRelationshipsTranslationsDataSchema](docs/CandidateRelationshipsTranslationsDataSchema.md)
 - [CandidateRelationshipsTranslationsSchema](docs/CandidateRelationshipsTranslationsSchema.md)
 - [CandidateResourceSchema](docs/CandidateResourceSchema.md)
 - [CandidateSchema](docs/CandidateSchema.md)
 - [CandidatesSchema](docs/CandidatesSchema.md)
 - [ChatAttributesSchema](docs/ChatAttributesSchema.md)
 - [ChatRelationshipsSchema](docs/ChatRelationshipsSchema.md)
 - [ChatRelationshipsTranslationsDataSchema](docs/ChatRelationshipsTranslationsDataSchema.md)
 - [ChatRelationshipsTranslationsSchema](docs/ChatRelationshipsTranslationsSchema.md)
 - [ChatResourceSchema](docs/ChatResourceSchema.md)
 - [ChatSchema](docs/ChatSchema.md)
 - [ChatsSchema](docs/ChatsSchema.md)
 - [ConversationAttributesSchema](docs/ConversationAttributesSchema.md)
 - [ConversationRelationshipsCandidateDataSchema](docs/ConversationRelationshipsCandidateDataSchema.md)
 - [ConversationRelationshipsCandidateSchema](docs/ConversationRelationshipsCandidateSchema.md)
 - [ConversationRelationshipsSchema](docs/ConversationRelationshipsSchema.md)
 - [ConversationResourceSchema](docs/ConversationResourceSchema.md)
 - [ConversationSchema](docs/ConversationSchema.md)
 - [ConversationsSchema](docs/ConversationsSchema.md)
 - [CreateAdRequestBody](docs/CreateAdRequestBody.md)
 - [CreateAdRequestBodyData](docs/CreateAdRequestBodyData.md)
 - [CreateApikeyRequestBody](docs/CreateApikeyRequestBody.md)
 - [CreateApikeyRequestBodyData](docs/CreateApikeyRequestBodyData.md)
 - [CreateAssessmentRequestBody](docs/CreateAssessmentRequestBody.md)
 - [CreateAssessmentRequestBodyData](docs/CreateAssessmentRequestBodyData.md)
 - [CreateBrowserRequestBody](docs/CreateBrowserRequestBody.md)
 - [CreateBrowserRequestBodyData](docs/CreateBrowserRequestBodyData.md)
 - [CreateCallRequestBody](docs/CreateCallRequestBody.md)
 - [CreateCallRequestBodyData](docs/CreateCallRequestBodyData.md)
 - [CreateCandidateRequestBody](docs/CreateCandidateRequestBody.md)
 - [CreateCandidateRequestBodyData](docs/CreateCandidateRequestBodyData.md)
 - [CreateChatRequestBody](docs/CreateChatRequestBody.md)
 - [CreateChatRequestBodyData](docs/CreateChatRequestBodyData.md)
 - [CreateConversationRequestBody](docs/CreateConversationRequestBody.md)
 - [CreateConversationRequestBodyData](docs/CreateConversationRequestBodyData.md)
 - [CreateEmailRequestBody](docs/CreateEmailRequestBody.md)
 - [CreateEmailRequestBodyData](docs/CreateEmailRequestBodyData.md)
 - [CreateFileRequestBody](docs/CreateFileRequestBody.md)
 - [CreateFileRequestBodyData](docs/CreateFileRequestBodyData.md)
 - [CreateFinderRequestBody](docs/CreateFinderRequestBody.md)
 - [CreateFinderRequestBodyData](docs/CreateFinderRequestBodyData.md)
 - [CreateFormRequestBody](docs/CreateFormRequestBody.md)
 - [CreateFormRequestBodyData](docs/CreateFormRequestBodyData.md)
 - [CreateJobRequestBody](docs/CreateJobRequestBody.md)
 - [CreateJobRequestBodyData](docs/CreateJobRequestBodyData.md)
 - [CreateLinkRequestBody](docs/CreateLinkRequestBody.md)
 - [CreateLinkRequestBodyData](docs/CreateLinkRequestBodyData.md)
 - [CreateMeetingAiSessionRequestBody](docs/CreateMeetingAiSessionRequestBody.md)
 - [CreateMeetingAiSessionRequestBodyData](docs/CreateMeetingAiSessionRequestBodyData.md)
 - [CreateMeetingAttendeeRequestBody](docs/CreateMeetingAttendeeRequestBody.md)
 - [CreateMeetingAttendeeRequestBodyData](docs/CreateMeetingAttendeeRequestBodyData.md)
 - [CreateMeetingRequestBody](docs/CreateMeetingRequestBody.md)
 - [CreateMeetingRequestBodyData](docs/CreateMeetingRequestBodyData.md)
 - [CreateNoteRequestBody](docs/CreateNoteRequestBody.md)
 - [CreateNoteRequestBodyData](docs/CreateNoteRequestBodyData.md)
 - [CreateNotificationRequestBody](docs/CreateNotificationRequestBody.md)
 - [CreateNotificationRequestBodyData](docs/CreateNotificationRequestBodyData.md)
 - [CreateOperationRequestBody](docs/CreateOperationRequestBody.md)
 - [CreateOperationRequestBodyData](docs/CreateOperationRequestBodyData.md)
 - [CreatePersonaRequestBody](docs/CreatePersonaRequestBody.md)
 - [CreatePersonaRequestBodyData](docs/CreatePersonaRequestBodyData.md)
 - [CreateReportRequestBody](docs/CreateReportRequestBody.md)
 - [CreateReportRequestBodyData](docs/CreateReportRequestBodyData.md)
 - [CreateRoleRequestBody](docs/CreateRoleRequestBody.md)
 - [CreateRoleRequestBodyData](docs/CreateRoleRequestBodyData.md)
 - [CreateTalentRequestBody](docs/CreateTalentRequestBody.md)
 - [CreateTalentRequestBodyData](docs/CreateTalentRequestBodyData.md)
 - [CreateTenantRequestBody](docs/CreateTenantRequestBody.md)
 - [CreateTenantRequestBodyData](docs/CreateTenantRequestBodyData.md)
 - [CreateTenantUploadRequestBody](docs/CreateTenantUploadRequestBody.md)
 - [CreateTenantUploadRequestBodyData](docs/CreateTenantUploadRequestBodyData.md)
 - [CreateTenantUploadRequestBodyDataAttributes](docs/CreateTenantUploadRequestBodyDataAttributes.md)
 - [CreateTranslationRequestBody](docs/CreateTranslationRequestBody.md)
 - [CreateTranslationRequestBodyData](docs/CreateTranslationRequestBodyData.md)
 - [CreateUserRequestBody](docs/CreateUserRequestBody.md)
 - [CreateUserRequestBodyData](docs/CreateUserRequestBodyData.md)
 - [CreateUserUploadRequestBody](docs/CreateUserUploadRequestBody.md)
 - [CreateUserUploadRequestBodyData](docs/CreateUserUploadRequestBodyData.md)
 - [CreateUserUploadRequestBodyDataAttributes](docs/CreateUserUploadRequestBodyDataAttributes.md)
 - [CreateWebhookRequestBody](docs/CreateWebhookRequestBody.md)
 - [CreateWebhookRequestBodyData](docs/CreateWebhookRequestBodyData.md)
 - [EmailAttributesSchema](docs/EmailAttributesSchema.md)
 - [EmailRelationshipsCandidateDataSchema](docs/EmailRelationshipsCandidateDataSchema.md)
 - [EmailRelationshipsCandidateSchema](docs/EmailRelationshipsCandidateSchema.md)
 - [EmailRelationshipsOperationDataSchema](docs/EmailRelationshipsOperationDataSchema.md)
 - [EmailRelationshipsOperationSchema](docs/EmailRelationshipsOperationSchema.md)
 - [EmailRelationshipsReportDataSchema](docs/EmailRelationshipsReportDataSchema.md)
 - [EmailRelationshipsReportSchema](docs/EmailRelationshipsReportSchema.md)
 - [EmailRelationshipsSchema](docs/EmailRelationshipsSchema.md)
 - [EmailRelationshipsTranslationsDataSchema](docs/EmailRelationshipsTranslationsDataSchema.md)
 - [EmailRelationshipsTranslationsSchema](docs/EmailRelationshipsTranslationsSchema.md)
 - [EmailResourceSchema](docs/EmailResourceSchema.md)
 - [EmailSchema](docs/EmailSchema.md)
 - [EmailsSchema](docs/EmailsSchema.md)
 - [ErrorObjectSchema](docs/ErrorObjectSchema.md)
 - [ErrorSchema](docs/ErrorSchema.md)
 - [FileAttributesSchema](docs/FileAttributesSchema.md)
 - [FileRelationshipsLinkDataSchema](docs/FileRelationshipsLinkDataSchema.md)
 - [FileRelationshipsLinkSchema](docs/FileRelationshipsLinkSchema.md)
 - [FileRelationshipsSchema](docs/FileRelationshipsSchema.md)
 - [FileResourceSchema](docs/FileResourceSchema.md)
 - [FileSchema](docs/FileSchema.md)
 - [FilesSchema](docs/FilesSchema.md)
 - [FinderAttributesSchema](docs/FinderAttributesSchema.md)
 - [FinderRelationshipsCandidatesDataSchema](docs/FinderRelationshipsCandidatesDataSchema.md)
 - [FinderRelationshipsCandidatesSchema](docs/FinderRelationshipsCandidatesSchema.md)
 - [FinderRelationshipsJobsDataSchema](docs/FinderRelationshipsJobsDataSchema.md)
 - [FinderRelationshipsJobsSchema](docs/FinderRelationshipsJobsSchema.md)
 - [FinderRelationshipsSchema](docs/FinderRelationshipsSchema.md)
 - [FinderRelationshipsTalentsDataSchema](docs/FinderRelationshipsTalentsDataSchema.md)
 - [FinderRelationshipsTalentsSchema](docs/FinderRelationshipsTalentsSchema.md)
 - [FinderRelationshipsUsersDataSchema](docs/FinderRelationshipsUsersDataSchema.md)
 - [FinderRelationshipsUsersSchema](docs/FinderRelationshipsUsersSchema.md)
 - [FinderResourceSchema](docs/FinderResourceSchema.md)
 - [FinderSchema](docs/FinderSchema.md)
 - [FindersSchema](docs/FindersSchema.md)
 - [FormAttributesSchema](docs/FormAttributesSchema.md)
 - [FormRelationshipsSchema](docs/FormRelationshipsSchema.md)
 - [FormRelationshipsTranslationsDataSchema](docs/FormRelationshipsTranslationsDataSchema.md)
 - [FormRelationshipsTranslationsSchema](docs/FormRelationshipsTranslationsSchema.md)
 - [FormResourceSchema](docs/FormResourceSchema.md)
 - [FormSchema](docs/FormSchema.md)
 - [FormsSchema](docs/FormsSchema.md)
 - [JobAttributesLocationItemSchema](docs/JobAttributesLocationItemSchema.md)
 - [JobAttributesOrganizationAddressSchema](docs/JobAttributesOrganizationAddressSchema.md)
 - [JobAttributesOrganizationSchema](docs/JobAttributesOrganizationSchema.md)
 - [JobAttributesSchema](docs/JobAttributesSchema.md)
 - [JobAttributesSettingsConversationCandidateInterviewSchema](docs/JobAttributesSettingsConversationCandidateInterviewSchema.md)
 - [JobAttributesSettingsConversationEmailContactSchema](docs/JobAttributesSettingsConversationEmailContactSchema.md)
 - [JobAttributesSettingsConversationEmailDelaysSchema](docs/JobAttributesSettingsConversationEmailDelaysSchema.md)
 - [JobAttributesSettingsConversationEmailSchema](docs/JobAttributesSettingsConversationEmailSchema.md)
 - [JobAttributesSettingsConversationPersonaInterviewSchema](docs/JobAttributesSettingsConversationPersonaInterviewSchema.md)
 - [JobAttributesSettingsConversationSchema](docs/JobAttributesSettingsConversationSchema.md)
 - [JobAttributesSettingsCriteriasSchema](docs/JobAttributesSettingsCriteriasSchema.md)
 - [JobAttributesSettingsOperationSchema](docs/JobAttributesSettingsOperationSchema.md)
 - [JobAttributesSettingsPersonaSchema](docs/JobAttributesSettingsPersonaSchema.md)
 - [JobAttributesSettingsSchema](docs/JobAttributesSettingsSchema.md)
 - [JobAttributesSiteItemSchema](docs/JobAttributesSiteItemSchema.md)
 - [JobCriteriaSchema](docs/JobCriteriaSchema.md)
 - [JobRelationshipsCandidatesDataSchema](docs/JobRelationshipsCandidatesDataSchema.md)
 - [JobRelationshipsCandidatesSchema](docs/JobRelationshipsCandidatesSchema.md)
 - [JobRelationshipsConversationsDataSchema](docs/JobRelationshipsConversationsDataSchema.md)
 - [JobRelationshipsConversationsSchema](docs/JobRelationshipsConversationsSchema.md)
 - [JobRelationshipsOperationsDataSchema](docs/JobRelationshipsOperationsDataSchema.md)
 - [JobRelationshipsOperationsSchema](docs/JobRelationshipsOperationsSchema.md)
 - [JobRelationshipsPersonasDataSchema](docs/JobRelationshipsPersonasDataSchema.md)
 - [JobRelationshipsPersonasSchema](docs/JobRelationshipsPersonasSchema.md)
 - [JobRelationshipsSchema](docs/JobRelationshipsSchema.md)
 - [JobRelationshipsTranslationsDataSchema](docs/JobRelationshipsTranslationsDataSchema.md)
 - [JobRelationshipsTranslationsSchema](docs/JobRelationshipsTranslationsSchema.md)
 - [JobResourceSchema](docs/JobResourceSchema.md)
 - [JobSchema](docs/JobSchema.md)
 - [JobsSchema](docs/JobsSchema.md)
 - [LinkAttributesSchema](docs/LinkAttributesSchema.md)
 - [LinkRelationshipsFileDataSchema](docs/LinkRelationshipsFileDataSchema.md)
 - [LinkRelationshipsFileSchema](docs/LinkRelationshipsFileSchema.md)
 - [LinkRelationshipsSchema](docs/LinkRelationshipsSchema.md)
 - [LinkResourceSchema](docs/LinkResourceSchema.md)
 - [LinkSchema](docs/LinkSchema.md)
 - [LinksSchema](docs/LinksSchema.md)
 - [ListCandidateJobsRelationship](docs/ListCandidateJobsRelationship.md)
 - [ListCandidateTalentsRelationship](docs/ListCandidateTalentsRelationship.md)
 - [ListJobCandidatesRelationship](docs/ListJobCandidatesRelationship.md)
 - [ListRoleUsersRelationship](docs/ListRoleUsersRelationship.md)
 - [ListTalentCandidatesRelationship](docs/ListTalentCandidatesRelationship.md)
 - [ListUserApikeysRelationship](docs/ListUserApikeysRelationship.md)
 - [ListUserJobsRelationship](docs/ListUserJobsRelationship.md)
 - [ListUserRolesRelationship](docs/ListUserRolesRelationship.md)
 - [MeetingAiSessionAttributesSchema](docs/MeetingAiSessionAttributesSchema.md)
 - [MeetingAiSessionAttributesSchemaRealtimeSession](docs/MeetingAiSessionAttributesSchemaRealtimeSession.md)
 - [MeetingAiSessionResourceSchema](docs/MeetingAiSessionResourceSchema.md)
 - [MeetingAiSessionSchema](docs/MeetingAiSessionSchema.md)
 - [MeetingAiSessionSettingsSchema](docs/MeetingAiSessionSettingsSchema.md)
 - [MeetingAttendeeAttributesSchema](docs/MeetingAttendeeAttributesSchema.md)
 - [MeetingAttendeeResourceSchema](docs/MeetingAttendeeResourceSchema.md)
 - [MeetingAttendeeResourceSchemaAllOfRelationships](docs/MeetingAttendeeResourceSchemaAllOfRelationships.md)
 - [MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting](docs/MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting.md)
 - [MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData](docs/MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData.md)
 - [MeetingAttendeeResponseAttributesSchema](docs/MeetingAttendeeResponseAttributesSchema.md)
 - [MeetingAttendeeSchema](docs/MeetingAttendeeSchema.md)
 - [MeetingAttributesSchema](docs/MeetingAttributesSchema.md)
 - [MeetingLobbyAttributesSchema](docs/MeetingLobbyAttributesSchema.md)
 - [MeetingLobbyResourceSchema](docs/MeetingLobbyResourceSchema.md)
 - [MeetingLobbySchema](docs/MeetingLobbySchema.md)
 - [MeetingRelationshipsParticipantsDataSchema](docs/MeetingRelationshipsParticipantsDataSchema.md)
 - [MeetingRelationshipsParticipantsSchema](docs/MeetingRelationshipsParticipantsSchema.md)
 - [MeetingRelationshipsSchema](docs/MeetingRelationshipsSchema.md)
 - [MeetingResourceSchema](docs/MeetingResourceSchema.md)
 - [MeetingSchema](docs/MeetingSchema.md)
 - [MeetingTranscriptionAttributesSchema](docs/MeetingTranscriptionAttributesSchema.md)
 - [MeetingTranscriptionRequestBody](docs/MeetingTranscriptionRequestBody.md)
 - [MeetingTranscriptionRequestBodyData](docs/MeetingTranscriptionRequestBodyData.md)
 - [MeetingTranscriptionSchema](docs/MeetingTranscriptionSchema.md)
 - [MeetingTranscriptionSchemaData](docs/MeetingTranscriptionSchemaData.md)
 - [MeetingTranscriptionSettingsSchema](docs/MeetingTranscriptionSettingsSchema.md)
 - [MeetingsSchema](docs/MeetingsSchema.md)
 - [NoteAttributesSchema](docs/NoteAttributesSchema.md)
 - [NoteRelationshipsCandidateDataSchema](docs/NoteRelationshipsCandidateDataSchema.md)
 - [NoteRelationshipsCandidateSchema](docs/NoteRelationshipsCandidateSchema.md)
 - [NoteRelationshipsOperationDataSchema](docs/NoteRelationshipsOperationDataSchema.md)
 - [NoteRelationshipsOperationSchema](docs/NoteRelationshipsOperationSchema.md)
 - [NoteRelationshipsReportDataSchema](docs/NoteRelationshipsReportDataSchema.md)
 - [NoteRelationshipsReportSchema](docs/NoteRelationshipsReportSchema.md)
 - [NoteRelationshipsSchema](docs/NoteRelationshipsSchema.md)
 - [NoteRelationshipsTranslationsDataSchema](docs/NoteRelationshipsTranslationsDataSchema.md)
 - [NoteRelationshipsTranslationsSchema](docs/NoteRelationshipsTranslationsSchema.md)
 - [NoteResourceSchema](docs/NoteResourceSchema.md)
 - [NoteSchema](docs/NoteSchema.md)
 - [NotesSchema](docs/NotesSchema.md)
 - [NotificationAttributesSchema](docs/NotificationAttributesSchema.md)
 - [NotificationRelationshipsSchema](docs/NotificationRelationshipsSchema.md)
 - [NotificationRelationshipsSchemaUsers](docs/NotificationRelationshipsSchemaUsers.md)
 - [NotificationRelationshipsSchemaUsersDataInner](docs/NotificationRelationshipsSchemaUsersDataInner.md)
 - [NotificationResourceSchema](docs/NotificationResourceSchema.md)
 - [NotificationSchema](docs/NotificationSchema.md)
 - [NotificationsSchema](docs/NotificationsSchema.md)
 - [OperationAttributesSchema](docs/OperationAttributesSchema.md)
 - [OperationRelationshipsCandidateDataSchema](docs/OperationRelationshipsCandidateDataSchema.md)
 - [OperationRelationshipsCandidateSchema](docs/OperationRelationshipsCandidateSchema.md)
 - [OperationRelationshipsJobDataSchema](docs/OperationRelationshipsJobDataSchema.md)
 - [OperationRelationshipsJobSchema](docs/OperationRelationshipsJobSchema.md)
 - [OperationRelationshipsSchema](docs/OperationRelationshipsSchema.md)
 - [OperationResourceSchema](docs/OperationResourceSchema.md)
 - [OperationSchema](docs/OperationSchema.md)
 - [OperationsSchema](docs/OperationsSchema.md)
 - [PersonaAttributesSchema](docs/PersonaAttributesSchema.md)
 - [PersonaRelationshipsCandidatesDataSchema](docs/PersonaRelationshipsCandidatesDataSchema.md)
 - [PersonaRelationshipsCandidatesSchema](docs/PersonaRelationshipsCandidatesSchema.md)
 - [PersonaRelationshipsOperationsDataSchema](docs/PersonaRelationshipsOperationsDataSchema.md)
 - [PersonaRelationshipsOperationsSchema](docs/PersonaRelationshipsOperationsSchema.md)
 - [PersonaRelationshipsSchema](docs/PersonaRelationshipsSchema.md)
 - [PersonaRelationshipsTalentsDataSchema](docs/PersonaRelationshipsTalentsDataSchema.md)
 - [PersonaRelationshipsTalentsSchema](docs/PersonaRelationshipsTalentsSchema.md)
 - [PersonaRelationshipsTranslationsDataSchema](docs/PersonaRelationshipsTranslationsDataSchema.md)
 - [PersonaRelationshipsTranslationsSchema](docs/PersonaRelationshipsTranslationsSchema.md)
 - [PersonaResourceSchema](docs/PersonaResourceSchema.md)
 - [PersonaSchema](docs/PersonaSchema.md)
 - [PersonasSchema](docs/PersonasSchema.md)
 - [PurchaseTenantPhoneNumberRequest](docs/PurchaseTenantPhoneNumberRequest.md)
 - [PurchaseTenantPhoneNumberRequestData](docs/PurchaseTenantPhoneNumberRequestData.md)
 - [PurchaseTenantPhoneNumberRequestDataAttributes](docs/PurchaseTenantPhoneNumberRequestDataAttributes.md)
 - [ReportAttributesSchema](docs/ReportAttributesSchema.md)
 - [ReportRelationshipsSchema](docs/ReportRelationshipsSchema.md)
 - [ReportRelationshipsTenantsDataSchema](docs/ReportRelationshipsTenantsDataSchema.md)
 - [ReportRelationshipsTenantsSchema](docs/ReportRelationshipsTenantsSchema.md)
 - [ReportResourceSchema](docs/ReportResourceSchema.md)
 - [ReportSchema](docs/ReportSchema.md)
 - [ReportsSchema](docs/ReportsSchema.md)
 - [ResourceIdentifierSchema](docs/ResourceIdentifierSchema.md)
 - [ResourceLinksSchema](docs/ResourceLinksSchema.md)
 - [ResourceRelationshipsLinksSchema](docs/ResourceRelationshipsLinksSchema.md)
 - [ResourceRelationshipsMetaSchema](docs/ResourceRelationshipsMetaSchema.md)
 - [ResourceSchema](docs/ResourceSchema.md)
 - [ResourceTimestampsSchema](docs/ResourceTimestampsSchema.md)
 - [ResourcesLinksSchema](docs/ResourcesLinksSchema.md)
 - [ResourcesMetaPageSchema](docs/ResourcesMetaPageSchema.md)
 - [ResourcesMetaSchema](docs/ResourcesMetaSchema.md)
 - [RoleAttributesSchema](docs/RoleAttributesSchema.md)
 - [RoleRelationshipsPermissionsDataSchema](docs/RoleRelationshipsPermissionsDataSchema.md)
 - [RoleRelationshipsPermissionsSchema](docs/RoleRelationshipsPermissionsSchema.md)
 - [RoleRelationshipsSchema](docs/RoleRelationshipsSchema.md)
 - [RoleRelationshipsUsersDataSchema](docs/RoleRelationshipsUsersDataSchema.md)
 - [RoleRelationshipsUsersSchema](docs/RoleRelationshipsUsersSchema.md)
 - [RoleResourceSchema](docs/RoleResourceSchema.md)
 - [RoleSchema](docs/RoleSchema.md)
 - [RolesSchema](docs/RolesSchema.md)
 - [TalentAlumniSchema](docs/TalentAlumniSchema.md)
 - [TalentAttributesDesiredContractLengthSchema](docs/TalentAttributesDesiredContractLengthSchema.md)
 - [TalentAttributesDesiredEmploymentTypeSchema](docs/TalentAttributesDesiredEmploymentTypeSchema.md)
 - [TalentAttributesDesiredRoleSchema](docs/TalentAttributesDesiredRoleSchema.md)
 - [TalentAttributesEmploymentTypeSchema](docs/TalentAttributesEmploymentTypeSchema.md)
 - [TalentAttributesSchema](docs/TalentAttributesSchema.md)
 - [TalentAttributesSocialLinkSchema](docs/TalentAttributesSocialLinkSchema.md)
 - [TalentAvailabilityReceivedCriteriaSchema](docs/TalentAvailabilityReceivedCriteriaSchema.md)
 - [TalentReceivedCriteriaSchema](docs/TalentReceivedCriteriaSchema.md)
 - [TalentReferralSchema](docs/TalentReferralSchema.md)
 - [TalentReferralSchemaReferrer](docs/TalentReferralSchemaReferrer.md)
 - [TalentRelationshipsCandidatesDataSchema](docs/TalentRelationshipsCandidatesDataSchema.md)
 - [TalentRelationshipsCandidatesSchema](docs/TalentRelationshipsCandidatesSchema.md)
 - [TalentRelationshipsFilesDataSchema](docs/TalentRelationshipsFilesDataSchema.md)
 - [TalentRelationshipsFilesSchema](docs/TalentRelationshipsFilesSchema.md)
 - [TalentRelationshipsOperationsDataSchema](docs/TalentRelationshipsOperationsDataSchema.md)
 - [TalentRelationshipsOperationsSchema](docs/TalentRelationshipsOperationsSchema.md)
 - [TalentRelationshipsSchema](docs/TalentRelationshipsSchema.md)
 - [TalentRelationshipsTranslationsDataSchema](docs/TalentRelationshipsTranslationsDataSchema.md)
 - [TalentRelationshipsTranslationsSchema](docs/TalentRelationshipsTranslationsSchema.md)
 - [TalentResourceSchema](docs/TalentResourceSchema.md)
 - [TalentSchema](docs/TalentSchema.md)
 - [TalentsSchema](docs/TalentsSchema.md)
 - [TenantAttributesAddressSchema](docs/TenantAttributesAddressSchema.md)
 - [TenantAttributesSchema](docs/TenantAttributesSchema.md)
 - [TenantAttributesSettingsSchema](docs/TenantAttributesSettingsSchema.md)
 - [TenantAttributesSettingsSchemaCalling](docs/TenantAttributesSettingsSchemaCalling.md)
 - [TenantResourceSchema](docs/TenantResourceSchema.md)
 - [TenantSchema](docs/TenantSchema.md)
 - [TenantUploadAttributesSchema](docs/TenantUploadAttributesSchema.md)
 - [TenantUploadResourceSchema](docs/TenantUploadResourceSchema.md)
 - [TenantUploadSchema](docs/TenantUploadSchema.md)
 - [TenantsMetaPageSchema](docs/TenantsMetaPageSchema.md)
 - [TenantsMetaSchema](docs/TenantsMetaSchema.md)
 - [TenantsSchema](docs/TenantsSchema.md)
 - [TimelineAttributesSchema](docs/TimelineAttributesSchema.md)
 - [TimelineAttributesSchemaChangesValue](docs/TimelineAttributesSchemaChangesValue.md)
 - [TimelineAttributesSchemaSummaryValue](docs/TimelineAttributesSchemaSummaryValue.md)
 - [TimelineAttributesSchemaSummaryValueUser](docs/TimelineAttributesSchemaSummaryValueUser.md)
 - [TimelineAttributesSchemaTimestamps](docs/TimelineAttributesSchemaTimestamps.md)
 - [TimelineResourceSchema](docs/TimelineResourceSchema.md)
 - [TimelineSchema](docs/TimelineSchema.md)
 - [TimelinesSchema](docs/TimelinesSchema.md)
 - [TranslationAttributesSchema](docs/TranslationAttributesSchema.md)
 - [TranslationRelationshipsCandidateDataSchema](docs/TranslationRelationshipsCandidateDataSchema.md)
 - [TranslationRelationshipsCandidateSchema](docs/TranslationRelationshipsCandidateSchema.md)
 - [TranslationRelationshipsJobDataSchema](docs/TranslationRelationshipsJobDataSchema.md)
 - [TranslationRelationshipsJobSchema](docs/TranslationRelationshipsJobSchema.md)
 - [TranslationRelationshipsReportDataSchema](docs/TranslationRelationshipsReportDataSchema.md)
 - [TranslationRelationshipsReportSchema](docs/TranslationRelationshipsReportSchema.md)
 - [TranslationRelationshipsSchema](docs/TranslationRelationshipsSchema.md)
 - [TranslationRelationshipsTalentDataSchema](docs/TranslationRelationshipsTalentDataSchema.md)
 - [TranslationRelationshipsTalentSchema](docs/TranslationRelationshipsTalentSchema.md)
 - [TranslationResourceSchema](docs/TranslationResourceSchema.md)
 - [TranslationSchema](docs/TranslationSchema.md)
 - [TranslationsSchema](docs/TranslationsSchema.md)
 - [UpdateAdRequestBody](docs/UpdateAdRequestBody.md)
 - [UpdateAdRequestBodyData](docs/UpdateAdRequestBodyData.md)
 - [UpdateApikeyRequestBody](docs/UpdateApikeyRequestBody.md)
 - [UpdateApikeyRequestBodyData](docs/UpdateApikeyRequestBodyData.md)
 - [UpdateAssessmentRequestBody](docs/UpdateAssessmentRequestBody.md)
 - [UpdateAssessmentRequestBodyData](docs/UpdateAssessmentRequestBodyData.md)
 - [UpdateBrowserRequestBody](docs/UpdateBrowserRequestBody.md)
 - [UpdateBrowserRequestBodyData](docs/UpdateBrowserRequestBodyData.md)
 - [UpdateCallRequestBody](docs/UpdateCallRequestBody.md)
 - [UpdateCallRequestBodyData](docs/UpdateCallRequestBodyData.md)
 - [UpdateCandidateRequestBody](docs/UpdateCandidateRequestBody.md)
 - [UpdateCandidateRequestBodyData](docs/UpdateCandidateRequestBodyData.md)
 - [UpdateChatRequestBody](docs/UpdateChatRequestBody.md)
 - [UpdateChatRequestBodyData](docs/UpdateChatRequestBodyData.md)
 - [UpdateConversationRequestBody](docs/UpdateConversationRequestBody.md)
 - [UpdateConversationRequestBodyData](docs/UpdateConversationRequestBodyData.md)
 - [UpdateEmailRequestBody](docs/UpdateEmailRequestBody.md)
 - [UpdateEmailRequestBodyData](docs/UpdateEmailRequestBodyData.md)
 - [UpdateFileRequestBody](docs/UpdateFileRequestBody.md)
 - [UpdateFileRequestBodyData](docs/UpdateFileRequestBodyData.md)
 - [UpdateFinderRequestBody](docs/UpdateFinderRequestBody.md)
 - [UpdateFinderRequestBodyData](docs/UpdateFinderRequestBodyData.md)
 - [UpdateFormRequestBody](docs/UpdateFormRequestBody.md)
 - [UpdateFormRequestBodyData](docs/UpdateFormRequestBodyData.md)
 - [UpdateJobRequestBody](docs/UpdateJobRequestBody.md)
 - [UpdateJobRequestBodyData](docs/UpdateJobRequestBodyData.md)
 - [UpdateLinkRequestBody](docs/UpdateLinkRequestBody.md)
 - [UpdateLinkRequestBodyData](docs/UpdateLinkRequestBodyData.md)
 - [UpdateMeetingRequestBody](docs/UpdateMeetingRequestBody.md)
 - [UpdateMeetingRequestBodyData](docs/UpdateMeetingRequestBodyData.md)
 - [UpdateNoteRequestBody](docs/UpdateNoteRequestBody.md)
 - [UpdateNoteRequestBodyData](docs/UpdateNoteRequestBodyData.md)
 - [UpdateNotificationRequestBody](docs/UpdateNotificationRequestBody.md)
 - [UpdateNotificationRequestBodyData](docs/UpdateNotificationRequestBodyData.md)
 - [UpdateNotificationRequestBodyDataAttributes](docs/UpdateNotificationRequestBodyDataAttributes.md)
 - [UpdateOperationRequestBody](docs/UpdateOperationRequestBody.md)
 - [UpdateOperationRequestBodyData](docs/UpdateOperationRequestBodyData.md)
 - [UpdatePersonaRequestBody](docs/UpdatePersonaRequestBody.md)
 - [UpdatePersonaRequestBodyData](docs/UpdatePersonaRequestBodyData.md)
 - [UpdateReportRequestBody](docs/UpdateReportRequestBody.md)
 - [UpdateReportRequestBodyData](docs/UpdateReportRequestBodyData.md)
 - [UpdateRoleRequestBody](docs/UpdateRoleRequestBody.md)
 - [UpdateRoleRequestBodyData](docs/UpdateRoleRequestBodyData.md)
 - [UpdateTalentRequestBody](docs/UpdateTalentRequestBody.md)
 - [UpdateTalentRequestBodyData](docs/UpdateTalentRequestBodyData.md)
 - [UpdateTenantRequestBody](docs/UpdateTenantRequestBody.md)
 - [UpdateTenantRequestBodyData](docs/UpdateTenantRequestBodyData.md)
 - [UpdateTranslationRequestBody](docs/UpdateTranslationRequestBody.md)
 - [UpdateTranslationRequestBodyData](docs/UpdateTranslationRequestBodyData.md)
 - [UpdateUserRequestBody](docs/UpdateUserRequestBody.md)
 - [UpdateUserRequestBodyData](docs/UpdateUserRequestBodyData.md)
 - [UpdateWebhookRequestBody](docs/UpdateWebhookRequestBody.md)
 - [UpdateWebhookRequestBodyData](docs/UpdateWebhookRequestBodyData.md)
 - [UserAttributesSchema](docs/UserAttributesSchema.md)
 - [UserHistoryEventSchema](docs/UserHistoryEventSchema.md)
 - [UserHistoryEventSchemaChallengeResponsesInner](docs/UserHistoryEventSchemaChallengeResponsesInner.md)
 - [UserHistoryEventSchemaEventFeedback](docs/UserHistoryEventSchemaEventFeedback.md)
 - [UserRelationshipsApikeysDataSchema](docs/UserRelationshipsApikeysDataSchema.md)
 - [UserRelationshipsApikeysSchema](docs/UserRelationshipsApikeysSchema.md)
 - [UserRelationshipsJobsDataSchema](docs/UserRelationshipsJobsDataSchema.md)
 - [UserRelationshipsJobsSchema](docs/UserRelationshipsJobsSchema.md)
 - [UserRelationshipsRoleDataSchema](docs/UserRelationshipsRoleDataSchema.md)
 - [UserRelationshipsRoleSchema](docs/UserRelationshipsRoleSchema.md)
 - [UserRelationshipsSchema](docs/UserRelationshipsSchema.md)
 - [UserResourceSchema](docs/UserResourceSchema.md)
 - [UserSchema](docs/UserSchema.md)
 - [UserUploadAttributesSchema](docs/UserUploadAttributesSchema.md)
 - [UserUploadResourceSchema](docs/UserUploadResourceSchema.md)
 - [UserUploadSchema](docs/UserUploadSchema.md)
 - [UsersSchema](docs/UsersSchema.md)
 - [WebhookAttributesSchema](docs/WebhookAttributesSchema.md)
 - [WebhookResourceSchema](docs/WebhookResourceSchema.md)
 - [WebhookSchema](docs/WebhookSchema.md)
 - [WebhooksSchema](docs/WebhooksSchema.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="OAuth2Auth"></a>
### OAuth2Auth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://auth.dev03-smartymeet.com/oauth2/authorize
- **Scopes**: 
 - **openid**: Grants access to openid
 - **email**: Grants access to email
 - **profile**: Grants access to profile


## Author

developer@smartymeet.com


